from django.core.exceptions import ValidationError
from django.utils.translation import ugettext_lazy as _
from six import string_types
from stdnum import isbn


def ISBNValidator(value):
    """ Check string is a valid ISBN number"""
    
    if not isinstance(value, string_types):
        raise ValidationError(_(u'Invalid ISBN: Not a string'))

    if len(value) != 10 and len(value) != 13:
        raise ValidationError(_(u'Invalid ISBN: Wrong length'))
    
    if not value.isdigit():
        raise ValidationError(_(u'Invalid ISBN: Only numbers are allowed'))

    if not isbn.is_valid(value):
        raise ValidationError(_(u'Invalid ISBN: Failed checksum'))



from django.core.exceptions import ValidationError
from isbn_field.validators import ISBNValidator
from django.test import SimpleTestCase


class ISBNValidatorTest(SimpleTestCase):

    def test_calidation(self):
        # Short
        with self.assertRaises(ValidationError):
            ISBNValidator('111')

        # Long
        with self.assertRaises(ValidationError):
            ISBNValidator('12345678901234')

        # ISBN w Error
        with self.assertRaises(ValidationError):
            ISBNValidator('0765348275')

        # Valid ISBN10
        ISBNValidator('0765348276')

        # Valid ISBN13
        ISBNValidator('9780765348272')




from .validators import ISBNValidator
from django.db.models import CharField


class ISBNField(CharField):

    def __init__(self, *args, **kwargs):

        # Max length is 13 chars for ISBN12
        kwargs['max_length'] = 13
        kwargs['verbose_name'] = u'ISBN'
        kwargs['validators'] = [ISBNValidator]
        super(ISBNField, self).__init__(*args, **kwargs)

    def formfield(self, **kwargs):
        defaults = {
            'max_length': 13,
            'min_length': 10,
            'validators': [ISBNValidator],
        }
        defaults.update(kwargs)
        return super(ISBNField, self).formfield(**defaults)

    def __unicode__(self):
        return self.value



from setuptools import setup

setup(
	name='django-isbn-field',
	version='0.3',
	description='Provides a model field to manage and validate isbn numbers',

	url='https://github.com/secnot/django-isbn-field',
	author='secnot',
	
	license='LPGL, see LICENSE file.',
	
        keywords=['django', 'isbn', 'field'],

	classifiers=[
        'Topic :: Utilities',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Intended Audience :: Developers',
        'Environment :: Web Environment',
        'Framework :: Django',
		'License :: OSI Approved :: GNU Lesser General Public License v3 (LGPLv3)',
        'Development Status :: 5 - Production/Stable',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3'], 

	# Package
	packages = ['isbn_field'],
	install_requires = ['Django', 'python-stdnum>=1.5', 'six'],
	zip_safe = False, 
	include_package_data=True,
)
